@@ -22,6 +22,7 @@ class DataMediator:
         `testProportion` (float): Percentage of data from experimental & control sets to holdout. \n
         `controlIDs` (list[str]): List of sample IDs in the control set. \n
         `experimentalIDs` (list[str]): List of sample IDs in the experimental set. \n
+        `externalIDs` (list[str]): List of sample IDs for external validation. \n
         `randomSeed` (int): Seed number to replicate psuedorandom sampling.
 
     [Optional]
@@ -146,7 +147,11 @@ class DataMediator:
         dataframe attached to this instance, into experimental
         & control dataframes.
         """
-
+        missingIDs = []
+        for ID in IDs:
+            if ID not in self.dataframe.index:
+                missingIDs.append(ID)
+        print(f"samples missing from feature data: {missingIDs}")
         return self.dataframe.loc[[ID for ID in IDs if ID in self.dataframe.index]]
 
     def __balance(
@@ -229,7 +234,7 @@ class DataMediator:
             self.__balance(self.balancingMethodCallback)
         self.trainTestSplit()
 
-    def trainTestSplit(self, stratifyByClass=True) -> None:
+    def trainTestSplit(self, stratifyByClass=True, samplingSpace="internal") -> None:
         """
         Split control (class 0) and experimental data (class 1) by a given proportion into training/validation sets.
         Also takes independent holdout if `holdoutProportion` was passed during initialization.
@@ -250,7 +255,21 @@ class DataMediator:
 
         self.featureIndex = allData.index.tolist()
 
-        if self.holdoutProportion:
+        if samplingSpace == "external":
+            testProportion = self.testProportion
+            (
+                self.holdout,
+                self.validation,
+                self.holdoutLabels,
+                self.validationLabels,
+            ) = train_test_split(
+                allData.astype(int),
+                allLabels,
+                test_size=testProportion,  # percentage if less than 1
+                stratify=allLabels if stratifyByClass else None,
+                random_state=self.randomSeed,
+            )
+        elif self.holdoutProportion:
             # calculate number of samples in validation group
             testProportion = int(self.testProportion * len(allData))
             (
